@@ -335,7 +335,7 @@ class Pageview(aegis.database.Row):
 class HydraType(aegis.database.Row):
     table_name = 'hydra_type'
     id_column = 'hydra_type_id'
-    data_columns = ('hydra_type_name', 'hydra_type_desc', 'priority_ndx', 'next_run_sql', 'claimed_dttm')
+    data_columns = ('hydra_type_name', 'hydra_type_desc', 'priority_ndx', 'next_run_sql', 'claimed_dttm', 'run_host')
 
     @classmethod
     def get_name(cls, hydra_type_name):
@@ -456,7 +456,7 @@ class HydraQueue(aegis.database.Row):
     @classmethod
     def scan(cls, limit=100):
         # XXX TODO using work_host, work_env
-        sql = "SELECT hydra_queue.*, hydra_type.hydra_type_name, hydra_type.next_run_sql, hydra_type.status FROM hydra_queue JOIN hydra_type USING (hydra_type_id) WHERE finish_dttm IS NULL AND hydra_queue.delete_dttm IS NULL ORDER BY create_dttm ASC LIMIT %s"
+        sql = "SELECT hydra_queue.*, hydra_type.hydra_type_name, hydra_type.next_run_sql, hydra_type.status FROM hydra_queue JOIN hydra_type USING (hydra_type_id) WHERE finish_dttm IS NULL AND hydra_queue.delete_dttm IS NULL ORDER BY hydra_queue.work_dttm ASC LIMIT %s"
         return db().query(sql, limit, cls=cls)
 
     @classmethod
@@ -471,6 +471,16 @@ class HydraQueue(aegis.database.Row):
         sql = "SELECT * FROM hydra_queue WHERE finish_dttm IS NULL AND hydra_type_id=%s AND work_data=%s"
         return db().query(sql, hydra_type_id, data, cls=cls)
 
+    @classmethod
+    def count_live(cls):
+        sql = "SELECT COUNT(*) AS queue_cnt FROM hydra_queue WHERE finish_dttm IS NULL AND delete_dttm IS NULL"
+        return db().get(sql, cls=cls)
+
+    @classmethod
+    def scan_type(cls, hydra_type_id):
+        sql = "SELECT * FROM hydra_queue WHERE finish_dttm IS NULL AND delete_dttm IS NULL AND hydra_type_id=%s"
+        return db().query(sql, hydra_type_id, cls=cls)
+
     def claim(self):
         sql = 'UPDATE hydra_queue SET claimed_dttm=NOW() WHERE hydra_queue_id=%s AND claimed_dttm IS NULL'
         return db().execute(sql, self['hydra_queue_id'])
@@ -526,9 +536,9 @@ class HydraQueue(aegis.database.Row):
     @classmethod
     def past_items(cls, minutes=15):
         if type(db()) is aegis.database.PostgresConnection:
-            sql = "SELECT * FROM hydra_queue WHERE work_dttm < NOW() - INTERVAL '%s MINUTE'" % int(minutes)
+            sql = "SELECT * FROM hydra_queue WHERE work_dttm < NOW() - INTERVAL '%s MINUTE' ORDER BY work_dttm ASC LIMIT 50" % int(minutes)
         elif type(db()) is aegis.database.MysqlConnection:
-            sql = "SELECT * FROM hydra_queue WHERE work_dttm < NOW() - INTERVAL %s MINUTE" % int(minutes)
+            sql = "SELECT * FROM hydra_queue WHERE work_dttm < NOW() - INTERVAL %s MINUTE ORDER BY work_dttm ASC LIMIT 50" % int(minutes)
         return db().query(sql, cls=cls)
 
     def run_now(self):
@@ -636,7 +646,7 @@ class Build(aegis.database.Row):
 
     @classmethod
     def get_live_build(cls, env):
-        sql = "SELECT * FROM build WHERE deploy_dttm IS NOT NULL AND deploy_exit_status=0 AND revert_dttm IS NULL AND env=%s ORDER BY deploy_dttm DESC LIMIT 1"
+        sql = "SELECT * FROM build WHERE deploy_dttm IS NOT NULL AND deploy_exit_status=0 AND revert_dttm IS NULL AND env=%s AND build_target <> 'admin' ORDER BY deploy_dttm DESC LIMIT 1"
         return db().get(sql, env, cls=cls)
 
     @classmethod
@@ -654,7 +664,7 @@ class Build(aegis.database.Row):
 
     @classmethod
     def scan_stale_builds(cls, env):
-        sql = "SELECT * FROM build WHERE env=%s AND deploy_dttm IS NOT NULL ORDER BY deploy_dttm DESC"
+        sql = "SELECT * FROM build WHERE env=%s AND deploy_dttm IS NOT NULL AND delete_dttm IS NULL ORDER BY deploy_dttm DESC"
         return db().query(sql, env, cls=cls)
 
     @classmethod
